"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPlugins = void 0;
var shared_1 = require("@dev-scripts/shared");
var copy_webpack_plugin_1 = require("copy-webpack-plugin");
var eslint_webpack_plugin_1 = require("eslint-webpack-plugin");
var mini_css_extract_plugin_1 = require("mini-css-extract-plugin");
var sass_lint_webpack_1 = require("sass-lint-webpack");
var webpack_1 = require("webpack");
var WebpackManifestPlugin = require('webpack-manifest-plugin').WebpackManifestPlugin;
var env = shared_1.getEnv();
var mode = shared_1.getDefaultMode();
var isDevelopment = mode === 'development';
var getPlugins = function (isClient, manifestSharedSeed) {
    if (isClient === void 0) { isClient = true; }
    if (manifestSharedSeed === void 0) { manifestSharedSeed = {}; }
    return [
        isClient && new sass_lint_webpack_1.default(),
        isClient && shared_1.devConfig.copy && new copy_webpack_plugin_1.default(shared_1.devConfig.copy),
        isClient &&
            new eslint_webpack_plugin_1.default({
                emitWarning: true,
                failOnError: true,
            }),
        isClient &&
            new mini_css_extract_plugin_1.default({
                filename: shared_1.normalizePath("" + shared_1.devConfig.cssOutputPath + (isDevelopment ? '[name].css' : '[name].[contenthash].css')),
                chunkFilename: shared_1.normalizePath("" + shared_1.devConfig.cssOutputPath + (isDevelopment ? '[id].css' : '[id].[contenthash].css')),
            }),
        isClient &&
            new WebpackManifestPlugin({
                fileName: 'asset-manifest.json',
                seed: manifestSharedSeed,
                writeToFileEmit: true,
            }),
        new webpack_1.default.DefinePlugin(env.stringified),
        new webpack_1.default.DefinePlugin({
            __SERVER__: !isClient,
            __BROWSER__: isClient,
        }),
    ].filter(Boolean);
};
exports.getPlugins = getPlugins;
//# sourceMappingURL=plugins.js.map